@@ -351,6 +351,7 @@ webkit_pref_callback_gnome_fonts (GSettings  *ephy_settings,
   if (g_settings_get_boolean (ephy_settings, key)) {
     g_object_set (webkit_settings,
                   "default-font-family", "serif",
+                  "serif-font-family", "serif",
                   "sans-serif-font-family", "sans-serif",
                   "monospace-font-family", "monospace",
                   "default-font-size", webkit_settings_font_size_to_pixels (12),
@@ -501,6 +502,9 @@ ephy_embed_prefs_init (gpointer user_data)
                                                        "enable-webaudio", TRUE, /* FIXME: https://bugs.webkit.org/show_bug.cgi?id=205334 */
                                                        "enable-webgl", TRUE, /* FIXME: https://bugs.webkit.org/show_bug.cgi?id=205335 */
                                                        "javascript-can-open-windows-automatically", TRUE,
+#if WEBKIT_CHECK_VERSION (2, 27, 90) && !WEBKIT_CHECK_VERSION (2, 30, 0)
+                                                       "allow-top-navigation-to-data-urls", FALSE,
+#endif
                                                        NULL);
 
   for (i = 0; i < G_N_ELEMENTS (webkit_pref_entries); i++) {
